package com.devnem0y.objects;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Animation;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.math.Rectangle;
import com.devnem0y.screens.GameScreen;

import static com.devnem0y.utils.Constants.*;

public class Player {

    public enum StateAnimation {
        IDLE,
        RUN,
        ATTACK,
        DAMAGE,
        DEATH,
    }

    private Rectangle bounds;
    private TextureAtlas playerAtlas;
    private Animation animIdleR, animRunR, animAttackR, animDamageR, animDeathR, animIdleL, animRunL, animAttackL, animDamageL, animDeathL;
    private Sprite frame1R, frame2R, frame3R, frame4R, frame5R, frame6R,
            frame7R, frame8R, frame9R, frame10R, frame11R, frame12R,
            frame1L, frame2L, frame3L, frame4L, frame5L, frame6L,
            frame7L, frame8L, frame9L, frame10L, frame11L, frame12L;

    public StateAnimation stateAnimation;
    private int direction;
    private float speed;
    private int hpActual, hpMax;
    private int exp;
    private int level;
    private int playerAttack;
    private boolean alive, fire;
    private int fireCount;
    private float timerRestart;

    public Player() {
        bounds = new Rectangle();
        playerAtlas = new TextureAtlas("image/player.atlas");
        initAnimations();
        bounds.width = 88;
        bounds.height = 88;
        bounds.setPosition(APP_WIDTH / 2 - bounds.width / 2, APP_HEIGHT / 2 - bounds.height / 2);
        direction = 0; // 0 - left 1 - right
        stateAnimation = StateAnimation.IDLE;
        speed = 30.2f * 12;
        hpMax = 100;
        hpActual = hpMax;
        playerAttack = 0;
        alive = true;
        fire = false;
        timerRestart = 0;
    }

    public void update(float delta) {
        inputHandler(delta);

        if (bounds.x <= 0) bounds.x = 0;
        if (bounds.x + bounds.width >= APP_WIDTH) bounds.x = APP_WIDTH - bounds.width;
        if (bounds.y <= 0) bounds.y = 0;
        if (bounds.y + bounds.height >= APP_HEIGHT) bounds.y = APP_HEIGHT - bounds.height;
    }

    public void render(SpriteBatch batch, float time) {
        switch (stateAnimation) {
            case IDLE:
                if (direction == 0) batch.draw((TextureRegion) animIdleL.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                else if (direction == 1) batch.draw((TextureRegion) animIdleR.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                break;
            case RUN:
                if (direction == 0) batch.draw((TextureRegion) animRunL.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                else if (direction == 1) batch.draw((TextureRegion) animRunR.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                break;
            case ATTACK:
                if (direction == 0) batch.draw((TextureRegion) animAttackL.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                else if (direction == 1) batch.draw((TextureRegion) animAttackR.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                break;
            case DAMAGE:
                if (direction == 0) batch.draw(frame10L, bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                else if (direction == 1) batch.draw(frame10R, bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                break;
            case DEATH:
                if (direction == 0) batch.draw((TextureRegion) animDeathL.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                else if (direction == 1) batch.draw((TextureRegion) animDeathR.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
                break;
            default:
                break;
        }
    }

    private void inputHandler(float delta) {
        if (isAlive()){
            if (Gdx.input.isKeyPressed(Input.Keys.A) && !fire) {
                direction = 0;
                bounds.x -= speed * delta;
                stateAnimation = StateAnimation.RUN;
            } else stateAnimation = StateAnimation.IDLE;
            if (Gdx.input.isKeyPressed(Input.Keys.D) && !fire) {
                direction = 1;
                bounds.x += speed * delta;
                stateAnimation = StateAnimation.RUN;
            }
            if (Gdx.input.isKeyPressed(Input.Keys.W) && !fire) {
                bounds.y += speed * delta;
                stateAnimation = StateAnimation.RUN;
            }
            if (Gdx.input.isKeyPressed(Input.Keys.S) && !fire) {
                bounds.y -= speed * delta;
                stateAnimation = StateAnimation.RUN;
            }
            if (Gdx.input.isKeyPressed(Input.Keys.K)) {
                stateAnimation = StateAnimation.ATTACK;
                createShotgunAttack();
            } else fire = false;
        }

        if (Gdx.input.isKeyPressed(Input.Keys.L)) {
            fire = false;
            stateAnimation = StateAnimation.DEATH;
        }
    }

    public void damage(float valAttaackEnemmy) {
        if (hpActual > 0) {
            hpActual -= valAttaackEnemmy;
            stateAnimation = StateAnimation.DAMAGE;
        } else {
            stateAnimation = StateAnimation.DEATH;
            timerRestart += Gdx.graphics.getDeltaTime();
            if (timerRestart > 3) {
                setAlive(false);
                GameScreen.gameState = GameScreen.GameState.PAUSE;
                GameScreen.gameTimer = 0;
            }
        }
    }

    public void levelUp() {
        if (exp > 1000) {
            level++;
            exp = 0;
        }
    }

    private void createShotgunAttack() {
        if (isAlive()) {
            fireCount++;
            if (fireCount > 2) {
                fireCount = 0;
                for (int i = 0; i < GameScreen.shotgunBullets.length; i++) {
                    if (!GameScreen.shotgunBullets[i].isAlive()) {
                        if (direction == 0) GameScreen.shotgunBullets[i].setup(bounds.x - 19, bounds.y + 25);
                        if (direction == 1) GameScreen.shotgunBullets[i].setup(bounds.x + 35, bounds.y + 25);
                        fire = true;
                    }
                }
            }
        }
    }

    private void initAnimations() {
        frame1R = new Sprite(playerAtlas.findRegion("frame1"));
        frame2R = new Sprite(playerAtlas.findRegion("frame2"));
        TextureRegion[] idleR = {frame1R, frame2R,};
        animIdleR = new Animation(1f/3f, idleR);
        animIdleR.setPlayMode(Animation.PlayMode.LOOP);

        frame1L = new Sprite(playerAtlas.findRegion("frame1left"));
        frame2L = new Sprite(playerAtlas.findRegion("frame2left"));
        TextureRegion[] idleL = {frame1L, frame2L,};
        animIdleL = new Animation(1f/3f, idleL);
        animIdleL.setPlayMode(Animation.PlayMode.LOOP);

        frame3R = new Sprite(playerAtlas.findRegion("frame3"));
        frame4R = new Sprite(playerAtlas.findRegion("frame4"));
        frame5R = new Sprite(playerAtlas.findRegion("frame5"));
        frame6R = new Sprite(playerAtlas.findRegion("frame6"));
        TextureRegion[] runR = {frame3R, frame4R,frame5R, frame6R,};
        animRunR = new Animation(1f/10f, runR);
        animRunR.setPlayMode(Animation.PlayMode.LOOP);

        frame3L = new Sprite(playerAtlas.findRegion("frame3left"));
        frame4L = new Sprite(playerAtlas.findRegion("frame4left"));
        frame5L = new Sprite(playerAtlas.findRegion("frame5left"));
        frame6L = new Sprite(playerAtlas.findRegion("frame6left"));
        TextureRegion[] runL = {frame3L, frame4L,frame5L, frame6L,};
        animRunL = new Animation(1f/10f, runL);
        animRunL.setPlayMode(Animation.PlayMode.LOOP);

        frame7R = new Sprite(playerAtlas.findRegion("frame7"));
        frame8R = new Sprite(playerAtlas.findRegion("frame8"));
        frame9R = new Sprite(playerAtlas.findRegion("frame9"));
        TextureRegion[] attackR = {frame7R, frame8R,frame9R,};
        animAttackR = new Animation(1f/7f, attackR);
        animAttackR.setPlayMode(Animation.PlayMode.LOOP);

        frame7L = new Sprite(playerAtlas.findRegion("frame7left"));
        frame8L = new Sprite(playerAtlas.findRegion("frame8left"));
        frame9L = new Sprite(playerAtlas.findRegion("frame9left"));
        TextureRegion[] attackL = {frame7L, frame8L,frame9L,};
        animAttackL = new Animation(1f/7f, attackL);
        animAttackL.setPlayMode(Animation.PlayMode.LOOP);

        frame10R = new Sprite(playerAtlas.findRegion("frame10"));
        frame11R = new Sprite(playerAtlas.findRegion("frame11"));
        frame12R = new Sprite(playerAtlas.findRegion("frame12"));
        TextureRegion[] deathR = {frame10R, frame11R,frame12R,};
        animDeathR = new Animation(1f/5f, deathR);
        animDeathR.setPlayMode(Animation.PlayMode.NORMAL);

        frame10L = new Sprite(playerAtlas.findRegion("frame10left"));
        frame11L = new Sprite(playerAtlas.findRegion("frame11left"));
        frame12L = new Sprite(playerAtlas.findRegion("frame12left"));
        TextureRegion[] deathL = {frame10L, frame11L,frame12L,};
        animDeathL = new Animation(1f/5f, deathL);
        animDeathL.setPlayMode(Animation.PlayMode.NORMAL);
    }

    public Rectangle getBounds() {
        return bounds;
    }

    public boolean isAlive() {
        return alive;
    }

    public void setAlive(boolean alive) {
        this.alive = alive;
    }

    public int getHpActual() {
        return hpActual;
    }

    public void setHpActual(int hpActual) {
        this.hpActual = hpActual;
    }

    public int getHpMax() {
        return hpMax;
    }

    public int getExp() {
        return exp;
    }

    public void setExp(int exp) {
        this.exp = exp;
    }

    public int getLevel() {
        return level;
    }

    public void dispose() {
        playerAtlas.dispose();
    }
}
