package com.devnem0y.objects.enemies;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.g2d.Animation;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.math.MathUtils;
import com.badlogic.gdx.math.Rectangle;

import static com.devnem0y.utils.Constants.APP_HEIGHT;
import static com.devnem0y.utils.Constants.APP_WIDTH;

public class MehoSpiderRight {

    private Rectangle bounds;
    private TextureAtlas enemyAtlas;
    private Animation animRunL, animRunR, animDeath;
    private Sprite frame1R, frame2R, frame3R, frame4R,
            frame1L, frame2L, frame3L, frame4L,
            frameExp1, frameExp2, frameExp3, frameExp4, frameExp5, frameExp6;

    private boolean alive;
    private float speed;
    private int direction;
    private float animTimer;

    public MehoSpiderRight() {
        bounds = new Rectangle();
        initAnimations();
        bounds.width = 69;
        bounds.height = 56.75f;
        bounds.setPosition(APP_WIDTH + MathUtils.random(60), MathUtils.random(APP_HEIGHT));
        speed = MathUtils.random(0.3f, 1.62f);
        alive = true;
        direction = 2;
        animTimer = 0f;
    }

    public void update(Rectangle playerBounds, float delta) {
        float x = bounds.x + (bounds.getWidth() / 2);
        float y = bounds.y;
        float dx = playerBounds.getX() + (playerBounds.getWidth() / 2);
        float dy = playerBounds.getY();

        if (isAlive()) {
            if (x != dx) {
                if (x > dx) bounds.x -= speed;
                else bounds.x += speed;
            }
            if (y != dy) {
                if (y > dy) bounds.y -=speed;
                else bounds.y +=speed;
            }
        }

        if (dx < x) direction = 0;
        else if (dx > x) direction = 1;
    }

    public  void render(SpriteBatch batch, float time) {
        if (isAlive()) {
            if (direction == 0) batch.draw((TextureRegion) animRunL.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
            if (direction == 1) batch.draw((TextureRegion) animRunR.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
        } else {
            batch.draw((TextureRegion) animDeath.getKeyFrame(time), bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight());
            animTimer += Gdx.graphics.getDeltaTime();
            if (animTimer > 0.3f) {
                recreate();
                animTimer = 0;
            }
        }
    }

    public void recreate() {
        bounds = new Rectangle();
        bounds.width = 69;
        bounds.height = 56.75f;
        bounds.setPosition(APP_WIDTH + MathUtils.random(60), MathUtils.random(APP_HEIGHT));
        speed = MathUtils.random(0.3f, 2.62f);
        direction = 2;
        animTimer = 0;
        alive = true;
    }

    private void initAnimations() {
        enemyAtlas = new TextureAtlas("image/enemy.atlas");
        frame1R = new Sprite(enemyAtlas.findRegion("frame1"));
        frame2R = new Sprite(enemyAtlas.findRegion("frame2"));
        frame3R = new Sprite(enemyAtlas.findRegion("frame3"));
        frame4R = new Sprite(enemyAtlas.findRegion("frame4"));
        TextureRegion[] runR = {frame1R, frame2R,frame3R, frame4R,};
        animRunR = new Animation(1f/10f, runR);
        animRunR.setPlayMode(Animation.PlayMode.LOOP);

        frame1L = new Sprite(enemyAtlas.findRegion("frame1left"));
        frame2L = new Sprite(enemyAtlas.findRegion("frame2left"));
        frame3L = new Sprite(enemyAtlas.findRegion("frame3left"));
        frame4L = new Sprite(enemyAtlas.findRegion("frame4left"));
        TextureRegion[] runL = {frame1L, frame2L,frame3L, frame4L,};
        animRunL = new Animation(1f/10f, runL);
        animRunL.setPlayMode(Animation.PlayMode.LOOP);

        frameExp1 = new Sprite(enemyAtlas.findRegion("frame5"));
        frameExp2 = new Sprite(enemyAtlas.findRegion("frame6"));
        frameExp3 = new Sprite(enemyAtlas.findRegion("frame7"));
        frameExp4 = new Sprite(enemyAtlas.findRegion("frame8"));
        frameExp5 = new Sprite(enemyAtlas.findRegion("frame9"));
        frameExp6 = new Sprite(enemyAtlas.findRegion("frame10"));
        TextureRegion[] exp = {frameExp1, frameExp2, frameExp3, frameExp4, frameExp5, frameExp6,};
        animDeath = new Animation(1f/7f, exp);
        animDeath.setPlayMode(Animation.PlayMode.LOOP);
    }

    public boolean isAlive() {
        return alive;
    }

    public void setAlive(boolean alive) {
        this.alive = alive;
    }

    public Rectangle getBounds() {
        return bounds;
    }

    public void dispose() {
        enemyAtlas.dispose();
    }
}
