package com.devnem0y.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.math.MathUtils;
import com.badlogic.gdx.scenes.scene2d.actions.Actions;
import com.badlogic.gdx.utils.viewport.StretchViewport;
import com.devnem0y.Application;
import com.devnem0y.objects.Player;
import com.devnem0y.objects.effects.Explosion;
import com.devnem0y.objects.enemies.MehoSpiderLeft;
import com.devnem0y.objects.enemies.MehoSpiderRight;
import com.devnem0y.objects.playerBullets.ShotgunBullet;
import com.devnem0y.utils.ButtonsMenu;

import static com.devnem0y.utils.Constants.APP_HEIGHT;
import static com.devnem0y.utils.Constants.APP_WIDTH;

public class GameScreen extends AbstractScreen{

    private static int level;

    public enum GameState {
        PLAY,
        PAUSE,
    }

    private OrthographicCamera camera;
    private Texture background;
    private BitmapFont font;
    private ButtonsMenu buttonsMenu;
    private float animTime = 0f;
    public static float gameTimer;
    private float enemyTimerRecreate;
    //private int level;
    public static GameState gameState;

    public static Player player;
    public static ShotgunBullet[] shotgunBullets;
    private MehoSpiderLeft[] mehoSpiderLeft;
    private MehoSpiderRight[] mehoSpiderRight;

    public GameScreen(final Application app) {
        super(app);
        this.camera = new OrthographicCamera();
        this.camera.setToOrtho(false, APP_WIDTH, APP_HEIGHT);

        stage.setViewport(new StretchViewport(APP_WIDTH, APP_HEIGHT, camera));
    }

    @Override
    public void show() {
        System.out.println("GAME");
        Gdx.input.setInputProcessor(stage);
        stage.clear();

        buttonsMenu = new ButtonsMenu(app);
        buttonsMenu.createMenu(stage);

        font = new BitmapFont(Gdx.files.internal("fonts/BradleyHandITC26.fnt"));
        font.setColor(Color.BLACK);
        gameTimer = 30f;
        enemyTimerRecreate = 0f;
        level = 1;
        background = new Texture("image/bg.jpg");
        player = new Player();
        mehoSpiderLeft = new MehoSpiderLeft[3];
        for (int i = 0; i < mehoSpiderLeft.length; i++) {
            mehoSpiderLeft[i] = new MehoSpiderLeft();
        }
        mehoSpiderRight = new MehoSpiderRight[3];
        for (int i = 0; i < mehoSpiderRight.length; i++) {
            mehoSpiderRight[i] = new MehoSpiderRight();
        }
        shotgunBullets = new ShotgunBullet[1];
        for (int i = 0; i < shotgunBullets.length; i++) {
            shotgunBullets[i] = new ShotgunBullet();
        }
        gameState = GameState.PLAY;
    }

    @Override
    public void update(float delta) {
        stage.act(delta);
        switch (gameState) {
            case PLAY:
                buttonsMenu.pauseGroup.addAction(Actions.moveTo(0, APP_HEIGHT + 300, 0.9f));
                player.update(delta);
                for (MehoSpiderLeft sl : mehoSpiderLeft) {
                    sl.update(player.getBounds(), delta);
                    if (player.isAlive()){
                        if (sl.getBounds().overlaps(player.getBounds())) {
                            player.damage(1f);
                        }
                    }
                }
                for (MehoSpiderRight sr : mehoSpiderRight) {
                    sr.update(player.getBounds(), delta);
                    if (player.isAlive()){
                        if (sr.getBounds().overlaps(player.getBounds())) {
                            player.damage(1f);
                        }
                    }
                }
                for (ShotgunBullet bs : shotgunBullets) {
                    if (bs.isAlive()) {
                        bs.update(player.getBounds());
                        for (MehoSpiderRight sr : mehoSpiderRight) {
                            if (bs.getBounds().overlaps(sr.getBounds())) {
                                sr.setAlive(false);
                                player.setExp(player.getExp() + 25);
                                player.levelUp();
                                bs.destroy();
                                break;
                            }
                        }
                        for (MehoSpiderLeft sl : mehoSpiderLeft) {
                            if (bs.getBounds().overlaps(sl.getBounds())) {
                                sl.setAlive(false);
                                player.setExp(player.getExp() + 25);
                                player.levelUp();
                                bs.destroy();
                                break;
                            }
                        }
                    }
                }
                break;
            case PAUSE:
                buttonsMenu.pauseGroup.addAction(Actions.moveTo(0, 0, 0.9f));
                if (Gdx.input.isKeyPressed(Input.Keys.SPACE)) {
                    gameState = GameState.PLAY;
                    player.setHpActual(player.getHpMax());
                    player.setAlive(true);
                    createLevel();
                }
                for (MehoSpiderLeft sl : mehoSpiderLeft) {
                    if (sl.isAlive()) sl.recreate();
                }
                for (MehoSpiderRight sr : mehoSpiderRight) {
                    if (sr.isAlive()) sr.recreate();
                }
                break;
            default:
                break;
        }
    }

    @Override
    public void render(float delta) {
        super.render(delta);
        app.batch.setProjectionMatrix(camera.combined);
        animTime += Gdx.graphics.getDeltaTime();
        app.batch.begin();
        app.batch.draw(background, 0, 0, APP_WIDTH, APP_HEIGHT);
        player.render(app.batch, animTime);
        switch (gameState) {
            case PLAY:
                for (MehoSpiderLeft sl: mehoSpiderLeft) {
                    sl.render(app.batch, animTime);
                }
                for (MehoSpiderRight sr: mehoSpiderRight) {
                    sr.render(app.batch, animTime);
                }
                for (ShotgunBullet bs : shotgunBullets) {
                    if (bs.isAlive()) bs.render(app.batch);
                }
                break;
            case PAUSE:
                //font.draw(app.batch, "press SPACE to continue", APP_WIDTH / 2 - 40, APP_HEIGHT / 2 - 3);
                break;
            default:
                break;
        }
        drawHUD();
        updateLevel(delta);
        app.batch.end();
        stage.draw();
    }

    private void drawHUD() {
        font.draw(app.batch, "Level: " + player.getLevel(), +10, APP_HEIGHT - 10);
        font.draw(app.batch, "HP: " + player.getHpActual(), +10, APP_HEIGHT - 30);
        font.draw(app.batch, "exp: " + player.getExp(), +10, APP_HEIGHT - 50);
    }

    private void updateLevel(float delta) {
        font.draw(app.batch, "STAGE: " + level, APP_WIDTH / 2 - 10, APP_HEIGHT - 10);
        if ((int)gameTimer < 10) {
            font.draw(app.batch, "0" + (int)gameTimer + " sec", APP_WIDTH / 2 - 10, APP_HEIGHT - 30);
        } else font.draw(app.batch, (int)gameTimer + " sec", APP_WIDTH / 2 - 10, APP_HEIGHT - 30);
        if (gameState == GameState.PLAY) {
            gameTimer -= delta;
            if (gameTimer < 0) {
                level++;
                createLevel();
                gameState = GameState.PAUSE;
                System.out.println("press SPACE to continue");
            }
        }
    }

    public static void createLevel() {
        if (level == 1) gameTimer = 30f;
        else if (level == 2) gameTimer = 35f;
        else if (level == 3) gameTimer = 40f;
        else if (level == 4) gameTimer = 45f;
        else if (level == 5) gameTimer = 60f;
        else if (level == 6) gameTimer = 70f;
        else if (level == 7) gameTimer = 90f;
        else if (level >= 8) gameTimer = 90f + MathUtils.random(10f, 40f);
    }

    @Override
    public void pause() {

    }

    @Override
    public void resume() {

    }

    @Override
    public void hide() {

    }

    @Override
    public void dispose() {
        super.dispose();
        player.dispose();
        for (MehoSpiderLeft sl : mehoSpiderLeft) sl.dispose();
        for (MehoSpiderRight sr : mehoSpiderRight) sr.dispose();
        for (ShotgunBullet sb : shotgunBullets) sb.dispose();
    }
}
