package com.devnem0y.utils;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.scenes.scene2d.Group;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Button;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.devnem0y.Application;
import com.devnem0y.managers.GameScreenManager;
import com.devnem0y.screens.GameScreen;

import static com.devnem0y.utils.Constants.*;

public class ButtonsMenu {

    private Application app;

    private Button play, restart, exit;
    private Button.ButtonStyle playStyle, restartStyle, exitStyle;
    public Group mainMenuGroup, pauseGroup;
    private Skin skin;

    public ButtonsMenu(Application app) {
        this.app = app;
        skin = new Skin();
        skin.addRegions(new TextureAtlas(Gdx.files.internal("image/buttons.atlas")));
    }

    public void createMenu(Stage stage) {
        initMenu(stage);
        initPause(stage);
    }

    private void initMenu(Stage stage) {
        mainMenuGroup = new Group();
        mainMenuGroup.setPosition(0, APP_HEIGHT + 300);

        playStyle = new Button.ButtonStyle();
        playStyle.down = skin.getDrawable("play");
        playStyle.up = skin.getDrawable("play");

        exitStyle = new Button.ButtonStyle();
        exitStyle.down = skin.getDrawable("exit");
        exitStyle.up = skin.getDrawable("exit");

        play = new Button(playStyle);
        play.setPosition(APP_WIDTH / 2 - 85, 180);
        play.setSize(170, 170);
        play.addListener(new ClickListener() {
            public boolean touchDown (InputEvent event, float x, float y, int pointer, int button) {
                System.out.println("PLAY: 1");
                return true;
            }

            public void touchUp (InputEvent event, float x, float y, int pointer, int button) {
                System.out.println("PLAY: 0");
                app.gsm.setScreen(GameScreenManager.STATE.GAME);
            }
        });

        exit = new Button(exitStyle);
        exit.setPosition(APP_WIDTH - 70, APP_HEIGHT - 70);
        exit.setSize(60, 60);
        exit.addListener(new ClickListener() {
            public boolean touchDown (InputEvent event, float x, float y, int pointer, int button) {
                System.out.println("EXIT: 1");
                return true;
            }

            public void touchUp (InputEvent event, float x, float y, int pointer, int button) {
                System.out.println("EXIT: 0");
                Gdx.app.exit();
            }
        });

        mainMenuGroup.addActor(play);
        mainMenuGroup.addActor(exit);
        stage.addActor(mainMenuGroup);
    }

    private void initPause(Stage stage) {
        pauseGroup = new Group();
        pauseGroup.setPosition(0, APP_HEIGHT + 300);

        restartStyle = new Button.ButtonStyle();
        restartStyle.down = skin.getDrawable("restart");
        restartStyle.up = skin.getDrawable("restart");

        exitStyle = new Button.ButtonStyle();
        exitStyle.down = skin.getDrawable("exit");
        exitStyle.up = skin.getDrawable("exit");

        restart = new Button(restartStyle);
        restart.setPosition(350f, 270f);
        restart.setSize(70f, 70f);
        restart.addListener(new ClickListener() {
            public boolean touchDown (InputEvent event, float x, float y, int pointer, int button) {
                System.out.println("RESTART: 1");
                return true;
            }

            public void touchUp (InputEvent event, float x, float y, int pointer, int button) {
                System.out.println("RESTART: 0");
                GameScreen.gameState = GameScreen.GameState.PLAY;
                GameScreen.player.setHpActual(GameScreen.player.getHpMax());
                GameScreen.player.setAlive(true);
                GameScreen.createLevel();
            }
        });

        exit = new Button(exitStyle);
        exit.setPosition(430f, 270);
        exit.setSize(70f, 70f);
        exit.addListener(new ClickListener() {
            public boolean touchDown (InputEvent event, float x, float y, int pointer, int button) {
                System.out.println("EXIT: 1");
                return true;
            }

            public void touchUp (InputEvent event, float x, float y, int pointer, int button) {
                System.out.println("EXIT: 0");
                Gdx.app.exit();
            }
        });

        pauseGroup.addActor(restart);
        pauseGroup.addActor(exit);
        stage.addActor(pauseGroup);
    }
}
